@@ -486,12 +486,16 @@ class LoadMaster(HttpClient):
             interface["cidr"] = address_cidr_split[1]
         return interface
 
-    def add_local_user(self, user, password, radius=False):
+    def add_local_user(self, user, password=None, radius=False):
         params = {
             'user': user,
-            'password': password,
             'radius': get_api_bool_string(radius),
         }
+        if password is None:
+            params['nopass'] = 'y'
+        else:
+            params['password'] = password
+
         response = self._get('/useraddlocal', params)
         return send_response(response)
 
