@@ -22,6 +22,7 @@ from requests.packages.urllib3.poolmanager import PoolManager
 from .exceptions import ValidationError
 
 IS_PY3 = sys.version[0] == '3'
+TIMEOUT = 5
 
 
 def validate_port(port):
@@ -72,3 +73,7 @@ def get_sub_vs_list_from_data(response_data):
                 full_data[value['VSIndex']] = value
                 subvs_entries.append(value['VSIndex'])
     return subvs_entries, full_data
+
+
+def get_api_bool_string(api_bool):
+    return 'y' if api_bool else 'n'
